==> nextcloud-app-deck-1%3A1.5.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/sq.js <==
OC.L10N.register(
    "deck",
    {
    "Deck" : "Shto paisjen U2F",
    "Personal" : "Personale",
    "Finished" : "Përfunduar",
    "To review" : "Për rishikim",
    "Action needed" : "Nevoitet veprim",
    "Later" : "Më vonë",
    "copy" : "kopjo",
    "To do" : "Për t'u bërë",
    "Doing" : "Duke e bërë",
    "Done" : "Përfunduar",
    "The file was uploaded" : "Skedari u ngarkua",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Kartela e ngarkuar tejkalon udhëzimin MAX_FILE_SIZE që qe përcaktuar te formulari HTML",
    "No file was uploaded" : "S’u ngarkua kartelë",
    "Missing a temporary folder" : "Mungon një dosje e përkohshme",
    "Cancel" : "Anullo",
    "File already exists" : "Skedari ekziston tashmë",
    "Do you want to overwrite it?" : "Doni ta rishkruani atë?",
    "Add card" : "Shto kartë",
    "Hide archived cards" : "Fsheh kartat e arkivuara ",
    "Show archived cards" : "Trego kartat e arkivuara",
    "Details" : "Detajet",
    "Sharing" : "Ndarje",
    "Tags" : "Etiketa",
    "Undo" : "Ktheje pas",
    "Can edit" : "Can edit",
    "Can share" : "Mund të ndaj",
    "Delete" : "Delete",
    "Edit" : "Edito",
    "Members" : "Anëtar",
    "Attachments" : "Bashkangjitjet",
    "Comments" : "Komentet",
    "Modified" : "Modifikuar ",
    "Created" : "U krijua",
    "Due date" : "Data e vendosur",
    "Remove due date" : "Hiq datën e mbarimit",
    "Select Date" : "Zgjidhni Datën",
    "Save" : "Ruaj",
    "Reply" : "Përgjigju",
    "Update" : "Përditëso",
    "Description" : "Përshkrim",
    "Formatting help" : "Ndihmë formatimi",
    "(group)" : "(grup)",
    "seconds ago" : "sekonda më parë",
    "Archived boards" : "Borde të arkivuara",
    "Shared with you" : "E ndarë me ju",
    "Board details" : "Detajet e Tabeles ",
    "Edit board" : "Tabela e editimeve",
    "Today" : "Sot",
    "Tomorrow" : "Nesër",
    "This week" : "Këtë javë"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-deck-1%3A1.7.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/sq.js <==
OC.L10N.register(
    "deck",
    {
    "Deck" : "Shto paisjen U2F",
    "Personal" : "Personale",
    "%s on %s" : "%s në %s",
    "Finished" : "Përfunduar",
    "To review" : "Për rishikim",
    "Action needed" : "Nevoitet veprim",
    "Later" : "Më vonë",
    "copy" : "kopjo",
    "To do" : "Për t'u bërë",
    "Doing" : "Duke e bërë",
    "Done" : "Përfunduar",
    "The file was uploaded" : "Skedari u ngarkua",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Kartela e ngarkuar tejkalon udhëzimin MAX_FILE_SIZE që qe përcaktuar te formulari HTML",
    "No file was uploaded" : "S’u ngarkua kartelë",
    "Missing a temporary folder" : "Mungon një dosje e përkohshme",
    "Invalid date, date format must be YYYY-MM-DD" : "Datë e pavlefshme, formati i datës duhet të jetë VVVV-MM-DD",
    "Cancel" : "Anullo",
    "Close" : "Mbylleni",
    "File already exists" : "Skedari ekziston tashmë",
    "Do you want to overwrite it?" : "Doni ta rishkruani atë?",
    "Add card" : "Shto kartë",
    "Hide archived cards" : "Fsheh kartat e arkivuara ",
    "Show archived cards" : "Trego kartat e arkivuara",
    "Details" : "Detajet",
    "Sharing" : "Ndarje",
    "Tags" : "Etiketa",
    "Undo" : "Ktheje pas",
    "Can edit" : "Can edit",
    "Can share" : "Mund të ndaj",
    "Owner" : "Zotëruesi",
    "Delete" : "Delete",
    "Edit" : "Edito",
    "Members" : "Anëtar",
    "Download" : "Shkarko",
    "Attachments" : "Bashkangjitjet",
    "Comments" : "Komentet",
    "Modified" : "Modifikuar ",
    "Created" : "U krijua",
    "Due date" : "Data e vendosur",
    "Remove due date" : "Hiq datën e mbarimit",
    "Select Date" : "Zgjidhni Datën",
    "Today" : "Sot",
    "Tomorrow" : "Nesër",
    "Save" : "Ruaj",
    "Reply" : "Përgjigju",
    "Update" : "Përditëso",
    "Description" : "Përshkrim",
    "Formatting help" : "Ndihmë formatimi",
    "(group)" : "(grup)",
    "List is empty" : "Lista është bosh",
    "seconds ago" : "sekonda më parë",
    "Archived boards" : "Borde të arkivuara",
    "Shared with you" : "E ndarë me ju",
    "Board details" : "Detajet e Tabeles ",
    "Edit board" : "Tabela e editimeve",
    "Unarchive board" : "Hiq bordin nga arkivi",
    "Archive board" : "Arkivo bordin",
    "No notifications" : "Asnjë njofim",
    "Delete board" : "Fshij bordin",
    "Share" : "Shpërndaje",
    "This week" : "Këtë javë"
},
"nplurals=2; plural=(n != 1);");
